starcluster.ssh.SSHGlob

Package starcluster :: Module ssh :: Class SSHGlob |
[hide private]
[frames] | no frames]

# Class SSHGlob

source code

Instance Methods | [hide private]
__init__(self, ssh_client) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
glob(self, pathname) | source code
iglob(self, pathname) Return an iterator which yields the paths matching a pathname pattern. | source code
glob0(self, dirname, basename) | source code
glob1(self, dirname, pattern) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, ssh_client) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### iglob(self, pathname) | source code
Return an iterator which yields the paths matching a pathname pattern. The pattern may contain simple shell-style wildcards a la fnmatch.